<?php
// app/Http/Controllers/BoothNumberController.php

namespace App\Http\Controllers\All;
use App\Models\EciData;
use App\Models\BoothNumber;
use App\Models\Country;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\BoothImport;

class BoothNumberController extends Controller
{
    public function index()
    {
        $booths = BoothNumber::where([])->orderBy('id' , 'desc')->paginate(50);
        return view('user.booth.index', compact('booths'));
    }

    public function truncate()
    {
        BoothNumber::truncate();
        return redirect()->back()->with('success', 'Data deleted successfully.');
    }

    public function create()
    {
        $country = Country::all();
        return view('user.booth.create', compact('country'));
    }

    public function store(Request $request)
    {
        //dd($_REQUEST);
        $request->validate([
            'name' => 'required|string'
        ]);

       
        BoothNumber::create([
            'name' => $request->name
        ]);

        return redirect()->route('user.booth.index')->with('success', 'BoothNumber added successfully');
    }

    public function edit($id)
    {
        $country = Country::all();
        $booth = BoothNumber::findOrFail($id);
        return view('user.booth.edit', compact('booth','country'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string'
        ]);
    
        $booth = BoothNumber::findOrFail($id);
    
        $BoothNumber = BoothNumber::updateOrCreate(
            ['id' => $booth->id],
            [
                'name' => $request->name
            ]
        );
        
        return redirect()->route('user.booth.index')->with('success', 'BoothNumber updated successfully');
    }

    public function destroy($id)
    {

        $EciData = EciData::where(['booth_number_id' => $id])->first();
        if($EciData){
            return redirect()->route('user.booth.index')->with('error', 'BoothNumber linked with ECI data');
        }
        // Find the MCQ category by ID
        $booth = BoothNumber::findOrFail($id);
    
        // Delete the MCQ category
        $booth->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.booth.index')->with('success', 'BoothNumber deleted successfully');
    }

    public function allBoothNumbers(Request $request)
    {
        $arr = [];
        $videos = BoothNumber::where()->get([
            'title', 
            'descriptions'
        ]);
        
        foreach($videos as $video){
            array_push($arr, array(
                'title' => $video->title, 
                'descriptions' => $video->descriptions
            ));  
        }
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $arr));
    }

    public function import(Request $request)
    {
        // Validate the file input
        $request->validate([
            'file' => 'required|mimes:csv,xlsx'
        ]);

        // Perform the import
        Excel::import(new BoothImport, $request->file('file'));

        return redirect()->back()->with('success', 'File imported successfully.');
    }

    public function bulkDelete(Request $request)
    {
        $ids = $request->input('ids');
        
        if ($ids) {
            // Check if any of the selected booth numbers are linked with ECI data
            $eciLinkedBooths = EciData::whereIn('booth_number_id', $ids)->get();
            
            if ($eciLinkedBooths->isNotEmpty()) {
                return redirect()->back()->with('error', 'Some Booth Numbers are linked with ECI data and cannot be deleted.');
            }
    
            // Proceed to delete booth numbers that are not linked with ECI data
            BoothNumber::whereIn('id', $ids)->delete();
            return redirect()->back()->with('success', 'Selected Booth Numbers deleted successfully.');
        }
    
        return redirect()->back()->with('error', 'No Booth Numbers selected for deletion.');
    }
    
}
