<?php
// app/Http/Controllers/ColonyController.php

namespace App\Http\Controllers\All;
use App\Models\EciData;
use App\Models\Colony;
use App\Models\Country;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\ColonyImport;

class ColonyController extends Controller
{
    public function index()
    {
        $colonys = Colony::where([])->orderBy('id' , 'desc')->paginate(50);
        return view('user.colony.index', compact('colonys'));
    }

    public function truncate()
    {
        Colony::truncate();
        return redirect()->back()->with('success', 'Data deleted successfully.');
    }

    public function create()
    {
        $country = Country::all();
        return view('user.colony.create', compact('country'));
    }

    public function store(Request $request)
    {
        //dd($_REQUEST);
        $request->validate([
            'name' => 'required|string',
        ]);

       
        Colony::create([
            'name' => $request->name
        ]);

        return redirect()->route('user.colony.index')->with('success', 'Colony added successfully');
    }

    public function edit($id)
    {
        $country = Country::all();
        $colony = Colony::findOrFail($id);
        return view('user.colony.edit', compact('colony','country'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string'
        ]);
    
        $colony = Colony::findOrFail($id);
    
        $Colony = Colony::updateOrCreate(
            ['id' => $colony->id],
            [
                'name' => $request->name
            ]
        );
        
        return redirect()->route('user.colony.index')->with('success', 'Colony updated successfully');
    }

    public function destroy($id)
    {
        $EciData = EciData::where(['colony_id' => $id])->first();
        if($EciData){
            return redirect()->route('user.colony.index')->with('error', 'BoothNumber linked with ECI data');
        }

        // Find the MCQ category by ID
        $colony = Colony::findOrFail($id);
    
        // Delete the MCQ category
        $colony->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.colony.index')->with('success', 'Colony deleted successfully');
    }

    public function allColonys(Request $request)
    {
        $arr = [];
        $videos = Colony::where()->get([
            'title', 
        ]);
        
        foreach($videos as $video){
            array_push($arr, array(
                'title' => $video->title, 
            ));  
        }
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $arr));
    }

    public function import(Request $request)
    {
        // Validate the file input
        $request->validate([
            'file' => 'required|mimes:csv,xlsx'
        ]);

        // Perform the import
        Excel::import(new ColonyImport, $request->file('file'));

        return redirect()->back()->with('success', 'File imported successfully.');
    }

    public function bulkDelete(Request $request)
    {
        $ids = $request->input('ids');
        
        if ($ids) {
            // Check if any of the selected colonies are linked with ECI data
            $eciLinkedColonies = EciData::whereIn('colony_id', $ids)->get();
            
            if ($eciLinkedColonies->isNotEmpty()) {
                return redirect()->back()->with('error', 'Some colonies are linked with ECI data and cannot be deleted.');
            }
    
            // Proceed to delete colonies that are not linked with ECI data
            Colony::whereIn('id', $ids)->delete();
            return redirect()->back()->with('success', 'Selected colonies deleted successfully.');
        }
    
        return redirect()->back()->with('error', 'No colonies selected for deletion.');
    }
    
    
}
