<?php
// app/Http/Controllers/ECIDataController.php

namespace App\Http\Controllers\All;
use App\Models\EciData;
use App\Models\EciUser;
use App\Models\Relation;
use App\Models\Country;
use App\Models\PollingStation;
use App\Models\Colony;
use App\Models\BoothNumber;
use App\Models\WordNumber;
use App\Imports\UsersImport;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;
use DB;
use Illuminate\Support\Facades\Response;
use Box\Spout\Reader\Common\Creator\ReaderEntityFactory;

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Csv;
use PhpOffice\PhpSpreadsheet\Style\Color;
use PhpOffice\PhpSpreadsheet\Style\Font;

class ECIDataController extends Controller
{
    public function index(Request $request)
    {
        $query = EciData::with(['country', 'state', 'city', 'polling_station', 'booth_number', 'colony']);
    
        // Apply filters based on request input
        if ($request->has('city') && $request->city != "") {
            // Search based on the city name in the related City model
            $query->whereHas('city', function ($q) use ($request) {
                $q->where('name', 'like', '%' . $request->input('city') . '%');
            });
        }
    
        if ($request->has('state') && $request->state != "") {
            // Search based on the state name in the related State model
            $query->whereHas('state', function ($q) use ($request) {
                $q->where('name', 'like', '%' . $request->input('state') . '%');
            });
        }
    
        if ($request->has('votar_id_no') && $request->votar_id_no != "") {
            // Search based on voter ID in the EciData table
            $query->where('votar_id_no', 'like', '%' . $request->input('votar_id_no') . '%');
        }
    
        if ($request->has('polling_station') && $request->polling_station != "") {
            // Search based on the polling station name in the related PollingStation model
            $query->whereHas('polling_station', function ($q) use ($request) {
                $q->where('name', 'like', '%' . $request->input('polling_station') . '%');
            });
        }
    
        if ($request->has('postal_code') && $request->postal_code != "") {
            // Search based on postal code in the EciData table
            $query->where('postal_code', 'like', '%' . $request->input('postal_code') . '%');
        }
    
        if ($request->has('ward_no') && $request->ward_no != "") {
            // Search based on ward number in the EciData table
            $query->where('ward_no', 'like', '%' . $request->input('ward_no') . '%');
        }
    
        if ($request->has('colony') && $request->colony != "") {
            // Search based on the colony name in the related Colony model
            $query->whereHas('colony', function ($q) use ($request) {
                $q->where('name', 'like', '%' . $request->input('colony') . '%');
            });
        }

        if ($request->has('booth') && $request->booth != "") {
            // Search based on the colony name in the related Colony model
            $query->whereHas('booth_number', function ($q) use ($request) {
                $q->where('name', 'like', '%' . $request->booth . '%');
            });
        }
        
        if ($request->has('keyword') && $request->keyword != "") {
            $keyword = $request->input('keyword');
            $keyword = str_replace(' ', '%', $keyword);
            $query->where(function($q) use ($keyword) {
                $q->where('votar_name', 'like', '%' . $keyword . '%')
                  ->orWhere('votar_id_no', 'like', '%' . $keyword . '%');
            });
        }
        
        if ($request->has('id') && $request->id != "") {
            $query->where('edi_users_id',   $request->input('id') );
        }
        
        // Paginate the results
        $ecidatas = $query->paginate(50);
        
        $total = $query->count();

        // Return the view with paginated data
        $eciUser = EciUser::all();
        
        return view('user.ecidata.index', compact('ecidatas', 'eciUser', 'total'));
    }
    
    public function create()
    {
        $country = Country::all();
        $polling_station = PollingStation::all();
        $colony = Colony::all();
        $booth_number = BoothNumber::all();
        $word_number = WordNumber::all();
        return view('user.ecidata.create', compact('country', 'polling_station', 'colony', 'booth_number', 'word_number' ));
    }

    public function store(Request $request)
    {
     
      // Validate the incoming request
            $validatedData = $request->validate([
                'edi_users_id' => 'string',
                'votar_id_no' => 'required|string',
                'votar_name' => 'required|string',
                'mobile' => 'required|string',
                'colony' => 'required|string',
                'gali_no' => 'required|string'
            ]);
            
        $result = EciData::where(['votar_id_no' => $request->votar_id_no])->get()->first();
        if($result){
             return redirect()->route('user.ecidata.index', ['id' => $request->edi_users_id])
                 ->with('error', 'votar id exist');
        }
        
        $result = EciUser::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' =>  $request->email,
        ]);
         
        
        EciData::create([
            'edi_users_id' => $result->id,
            'ac_no' => $request->ac_no,
            'ward_no' => $request->ward_no,
            'part_no' => $request->part_no,
            'section' => $request->section,
            'sl_no' => $request->sl_no,
            'votar_id_no' => $request->votar_id_no,
            'votar_name' => $request->votar_name,
            'mobile' => $request->mobile,
            'house_number' => $request->house_number,
            'age' => $request->age,
            'sex' => $request->sex,
            'polling_station_id' => $request->polling_station,
            'colony_id' => $request->colony,
            'block' => $request->block,
            'gali_no_id' => $request->gali_no,
            'country_id' => $request->country,
            'city_id' => $request->city,
            'state_id' => $request->state,
            'postal_code' => $request->pincode,
            'booth_number_id' => $request->booth_number,


            'relative_name' => $request->relative_name,
            'parent_state' => $request->parent_state,
            'parent_district' => $request->parent_district,
            'religion' => $request->religion,
            'cast' => $request->cast,
            'dob' => $request->dob,
            'marriage_date' => $request->marriage_date,
            'profession' => $request->profession,
            'remarks' => $request->remarks,
           
            'created_at' => date("Y-m-d H:i:s"),
            'updated_at' => date("Y-m-d H:i:s")
        ]);

        return redirect()->route('user.ecidata.index', ['id' => $request->edi_users_id])
                 ->with('success', 'Eci user added successfully');
    }

    public function edit($id)
    {
        $ecidata = EciData::findOrFail($id);
        $country = Country::all();
        $polling_station = PollingStation::all();
        $colony = Colony::all();
        $booth_number = BoothNumber::all();
        $word_number = WordNumber::all();
        return view('user.ecidata.edit', compact('ecidata', 'country','polling_station', 'colony', 'booth_number', 'word_number' ));
    }
    

    public function update(Request $request, $id)
    {
 
  // Validate the incoming request
            $validatedData = $request->validate([
                'edi_users_id' => 'string',
                'votar_id_no' => 'required|string',
                'votar_name' => 'required|string',
                'mobile' => 'required|string',
                'colony' => 'required|string',
                'gali_no' => 'required|string'
            ]);
            
        $result = EciData::where('votar_id_no', $request->votar_id_no)
                  ->where('id', '!=', $id)
                  ->first();
                  
        if($result){
             return redirect()->route('user.ecidata.index', ['id' => $request->edi_users_id])
                 ->with('error', 'votar id exist');
        }
 
        $ecidata = EciData::findOrFail($id);
    
        $EciData = EciData::updateOrCreate(
            ['id' => $ecidata->id],
            [
                'ac_no' => $request->ac_no,
                'ward_no' => $request->ward_no,
                'part_no' => $request->part_no,
                'section' => $request->section,
                'sl_no' => $request->sl_no,
                'votar_id_no' => $request->votar_id_no,
                'votar_name' => $request->votar_name,
                'mobile' => $request->mobile,
                'house_number' => $request->house_number,
                'age' => $request->age,
                'sex' => $request->sex,
                'polling_station_id' => $request->polling_station,
                'colony_id' => $request->colony,
                'block' => $request->block,
                'gali_no_id' => $request->gali_no,
                'country_id' => $request->country,
                'city_id' => $request->city,
                'state_id' => $request->state,
                'postal_code' => $request->pincode,
                'booth_number_id' => $request->booth_number,

                'relative_name' => $request->relative_name,
                'parent_state' => $request->parent_state,
                'parent_district' => $request->parent_district,
                'religion' => $request->religion,
                'cast' => $request->cast,
                'dob' => $request->dob,
                'marriage_date' => $request->marriage_date,
                'profession' => $request->profession,
                'remarks' => $request->remarks,
            ]
        );
        
        if($request->edi_users_id && $request->edi_users_id != ""){
            return redirect()->route('user.ecidata.index', ['id' => $request->edi_users_id])->with('success', 'Eci user updated successfully');
        }else{
            return redirect()->route('user.ecidata.index')->with('success', 'Eci user updated successfully');
        }
       
    }

    public function relationship(Request $request)
    {
        $request->validate([
            'relation' => 'string',
        ]);

        $result = EciData::where(['votar_id_no' => $request->votar_card])->get()->first();
        if(!$result){
            return redirect()->route('user.ecidata.index', ['id' => $request->edi_users_id])
            ->with('error', 'Votar id card not found');
        }
        

        Relation::updateOrCreate(
            [
                // Criteria for matching an existing record
                'edi_users_id' => $request->edi_users_id,
                'relation_name' => $request->name,
            ],
            [
                // Fields to update or insert
                'parent' => $result->id,
                'source' => $request->id,
            ]
        );
        return redirect()->route('user.ecidata.index', ['id' => $request->edi_users_id])
                 ->with('success', 'Relationship updated successfully');

     }

   
     public function destroy($id)
    {
        // Find the MCQ category by ID
        $ecidata = EciData::findOrFail($id);
    
        // Delete the MCQ category
        $ecidata->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.ecidata.index')->with('success', 'Eci user deleted successfully');
    }
    
    public function bulkDelete(Request $request)
    {
        $ids = $request->input('ids');
        
        if ($ids) {
            Relation::whereIn('parent', $ids)->delete();
            Relation::whereIn('source', $ids)->delete();
            EciData::whereIn('id', $ids)->delete();
            return redirect()->back()->with('success', 'Selected Booth Numbers deleted successfully.');
        }
    
        return redirect()->back()->with('error', 'No Booth Numbers selected for deletion.');
    }

    public function allEciDatas(Request $request)
    {
        $arr = [];
        $videos = EciData::where()->get();
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $videos));
    }

    // public function import(Request $request)
    // {
    //     $request->validate([
    //         'file' => 'required|mimes:csv,xlsx'
    //     ]);
        
    //     Excel::import(new UsersImport, $request->file('file'));
        
    //     return redirect()->back()->with('success', 'Users imported successfully.');
    // }

    public function import(Request $request)
    {
        // Validate the uploaded file
        $request->validate([
            'file' => 'required|mimes:xlsx,csv',
        ]);

        // Get the uploaded file
        $file = $request->file('file');

        // Get the file extension
        $extension = $file->getClientOriginalExtension();

        // Determine the reader based on the file extension
        if ($extension === 'xlsx') {
            $reader = ReaderEntityFactory::createXLSXReader();
        } elseif ($extension === 'csv') {
            $reader = ReaderEntityFactory::createCSVReader();
        } else {
            return redirect()->back()->with('error', 'Unsupported file format.');
        }

        // Open the file for reading
        $reader->open($file->getRealPath());

        // Counter for row number
        $rowNumber = 0;

        // Iterate through the sheets and rows in the file
        foreach ($reader->getSheetIterator() as $sheet) {
            foreach ($sheet->getRowIterator() as $row) {
                $cells = $row->getCells();
                $rowData = [];

                foreach ($cells as $cell) {
                    $rowData[] = $cell->getValue();  // Collect cell data
                }

                // Skip the first row if it contains headers
                if ($rowNumber === 0) {
                    $rowNumber++;
                    continue; // Skip headers
                }

                // Make sure the array index exists before accessing it
                $ediUsersId = isset($rowData[0]) && is_numeric($rowData[0]) ? intval($rowData[0]) : '';
                $countryId = isset($rowData[2]) && is_numeric($rowData[2]) ? intval($rowData[2]) : '';
                $cityId = isset($rowData[3]) && is_numeric($rowData[3]) ? intval($rowData[3]) : '';

                // Using isset to ensure array key exists before accessing it
                EciData::updateOrCreate(
                    ['votar_id_no' => isset($rowData[10]) ? $rowData[10] : ''],  // Assuming 'votar_id_no' is at index 10
                    [
                        'edi_users_id' => isset($rowData[0]) && is_numeric($rowData[0]) ? intval($rowData[0]) : '',
                        'ac_no' => isset($rowData[1]) ? $rowData[1] : '',
                        'country_id' => isset($rowData[2]) && is_numeric($rowData[2]) ? intval($rowData[2]) : '',
                        'city_id' => isset($rowData[3]) && is_numeric($rowData[3]) ? intval($rowData[3]) : null,
                        'state_id' => isset($rowData[4]) && is_numeric($rowData[4]) ? intval($rowData[4]) : null,  // Ensure valid integer
                        'postal_code' => isset($rowData[5]) ? $rowData[5] : '',
                        'ward_no' => isset($rowData[6]) && is_numeric($rowData[6]) ? intval($rowData[6]) : '',
                        'part_no' => isset($rowData[7]) && is_numeric($rowData[7]) ? intval($rowData[7]) : '',
                        'section' => isset($rowData[8]) ? $rowData[8] : '',
                        'sl_no' => isset($rowData[9]) ? $rowData[9] : '',
                        'votar_name' => isset($rowData[11]) ? $rowData[11] : '',
                        'mobile' => isset($rowData[12]) ? $rowData[12] : '',
                        'house_number' => isset($rowData[13]) ? $rowData[13] : '',
                        'age' => isset($rowData[14]) && is_numeric($rowData[14]) ? intval($rowData[14]) : '',
                        'sex' => isset($rowData[15]) ? $rowData[15] : '',
                        'polling_station_id' => isset($rowData[16]) && is_numeric($rowData[16]) ? intval($rowData[16]) : null,
                        'colony_id' => isset($rowData[17]) && is_numeric($rowData[17]) ? intval($rowData[17]) : null,
                        'block' => isset($rowData[18]) ? $rowData[18] : '',
                        'gali_no' => isset($rowData[19]) ? $rowData[19] : '',
                        'votar_id_front' => isset($rowData[20]) ? $rowData[20] : '',
                        'votar_id_back' => isset($rowData[21]) ? $rowData[21] : '',
                        'relation' => isset($rowData[22]) ? $rowData[22] : '',
                        'booth_number_id' => isset($rowData[23]) && is_numeric($rowData[23]) ? intval($rowData[23]) : '',
                        'relative_name' => isset($rowData[24]) ? $rowData[24] : '',
                        'parent_state' => isset($rowData[25]) && is_numeric($rowData[25]) ? intval($rowData[25]) : '',  // Check for numeric value
                        'parent_district' => isset($rowData[26]) && is_numeric($rowData[26]) ? intval($rowData[26]) : '',
                        'religion' => isset($rowData[27]) ? $rowData[27] : '',
                        'cast' => isset($rowData[28]) ? $rowData[28] : '',
                        'dob' => isset($rowData[29]) ? $rowData[29] : '',
                        'marriage_date' => isset($rowData[30]) ? $rowData[30] : '',
                        'profession' => isset($rowData[31]) ? $rowData[31] : '',
                        'remarks' => isset($rowData[32]) ? $rowData[32] : '',
                    ]
                );
            }
        }

        // Close the reader
        $reader->close();

        // Redirect back with a success message
        return redirect()->back()->with('success', 'Excel data imported successfully.');
    }

    public function export()
    {
        // Retrieve all ECI data with related country, city, and state information
        $ecidatas = EciData::with(['country', 'state', 'city', 'polling_station', 'booth_number', 'colony'])->get();
    
        // Define CSV headers (add more fields as needed)
        $headers = [
            'Votar ID No', 'Votar Name', 'Mobile', 'House Number', 'Age', 'Sex', 
            'Country', 'State', 'City', 'Postal Code', 'Polling Station', 'Booth Number', 'Colony',
            'Relative Name', 'Parent State', 'Parent District', 'Religion', 'Cast', 'DOB', 'Marriage Date', 
            'Profession', 'Remarks'
        ];
    
        // Open the output stream
        $callback = function() use ($ecidatas, $headers) {
            $file = fopen('php://output', 'w');
            fputcsv($file, $headers);
    
            // Loop through each ECI data entry
            foreach ($ecidatas as $data) {
                fputcsv($file, [
                    $data->votar_id_no,
                    $data->votar_name,
                    $data->mobile,
                    $data->house_number,
                    $data->age,
                    $data->sex,
                    $data->country ? $data->country->name : '',
                    $data->state ? $data->state->name : '',
                    $data->city ? $data->city->name : '',
                    $data->postal_code,
                    $data->polling_station ? $data->polling_station->name : '',
                    $data->booth_number ? $data->booth_number->name : '',
                    $data->colony ? $data->colony->name : '',
                    $data->relative_name,
                    $data->parent_state,
                    $data->parent_district,
                    $data->religion,
                    $data->cast,
                    $data->dob,
                    $data->marriage_date,
                    $data->profession,
                    $data->remarks
                ]);
            }
    
            fclose($file);
        };
    
        // Return response as CSV
        return response()->stream($callback, 200, [
            "Content-type" => "text/csv",
            "Content-Disposition" => "attachment; filename=eci_data.csv",
            "Pragma" => "no-cache",
            "Cache-Control" => "must-revalidate, post-check=0, pre-check=0",
            "Expires" => "0"
        ]);
    }
    
     public function truncate()
    {
        Relation::truncate();
        EciData::truncate();
        //DB::table('eci_data')->delete();
        return redirect()->back()->with('success', 'Data deleted successfully.');
    }
    
    
   public function family(Request $request)
{
    $perPage = $request->get('per_page', 10); // You can pass ?per_page=10 as a query parameter
    $page = $request->get('page', 1); // You can pass ?page=1 as a query parameter

    // Build the query for distinct sources
    $distinctQuery = Relation::where('edi_users_id', $request->edi_users_id);

    // Apply the keyword filter for counting distinct sources
    if ($request->filled('keyword')) {
        $keyword = $request->input('keyword');
        $keywords = array_filter(explode(' ', trim($keyword)));

        $distinctQuery->where(function ($q) use ($keywords) {
            // Search within the `source` table's fields
            $q->whereHas('source', function ($subQuery) use ($keywords) {
                foreach ($keywords as $word) {
                    $subQuery->where(function ($sq) use ($word) {
                        $sq->where('votar_name', 'like', '%' . $word . '%')
                           ->orWhere('votar_id_no', 'like', '%' . $word . '%')
                           ->orWhere('relative_name', 'like', '%' . $word . '%')
                           ->orWhere('sl_no', 'like', '%' . $word . '%');
                    });
                }
            });

            // Search within the related `booth_number` table's `name` field
            $q->orWhereHas('source.booth_number', function ($subQuery) use ($keywords) {
                foreach ($keywords as $word) {
                    $subQuery->where('name', 'like', '%' . $word . '%');
                }
            });

            // Search within the related `colony` table's `name` field
            $q->orWhereHas('source.colony', function ($subQuery) use ($keywords) {
                foreach ($keywords as $word) {
                    $subQuery->where('name', 'like', '%' . $word . '%');
                }
            });
        });
    }

    // Get the distinct count of sources
    $distinctTotal = $distinctQuery->distinct('source')->count('source');

    // Build the main query for pagination
    $query = Relation::query();
    $query->where('edi_users_id', $request->edi_users_id);

    // Apply the same keyword filter to the main query
    if ($request->filled('keyword')) {
        $keyword = $request->input('keyword');
        $keywords = array_filter(explode(' ', trim($keyword)));

        $query->where(function ($q) use ($keywords) {
            // Search within the `source` table's fields
            $q->whereHas('source', function ($subQuery) use ($keywords) {
                foreach ($keywords as $word) {
                    $subQuery->where(function ($sq) use ($word) {
                        $sq->where('votar_name', 'like', '%' . $word . '%')
                           ->orWhere('votar_id_no', 'like', '%' . $word . '%')
                           ->orWhere('relative_name', 'like', '%' . $word . '%')
                           ->orWhere('sl_no', 'like', '%' . $word . '%');
                    });
                }
            });

            // Search within the related `booth_number` table's `name` field
            $q->orWhereHas('source.booth_number', function ($subQuery) use ($keywords) {
                foreach ($keywords as $word) {
                    $subQuery->where('name', 'like', '%' . $word . '%');
                }
            });

            // Search within the related `colony` table's `name` field
            $q->orWhereHas('source.colony', function ($subQuery) use ($keywords) {
                foreach ($keywords as $word) {
                    $subQuery->where('name', 'like', '%' . $word . '%');
                }
            });
        });
    }

    /////////
    /////////
    /////////

    if ($request->filled('votar_id_no')) {
        $votar_id_no = trim($request->input('votar_id_no'));
        $query->where(function ($q) use ($votar_id_no) {
            $q->whereHas('source', function ($subQuery) use ($votar_id_no) {
                $subQuery->where('votar_id_no', 'like', '%' . $votar_id_no . '%');
            });
        });
    }

    if ($request->filled('polling_station')) {
        $polling_station = trim($request->input('polling_station'));
        $query->where(function ($q) use ($polling_station) {
            $q->whereHas('source', function ($subQuery) use ($polling_station) {
                $subQuery->whereHas('polling_station', function ($sq) use ($polling_station) {
                    $sq->where('name', 'like', '%' . $polling_station . '%');
                });
            });
        });
    }

    if ($request->filled('city')) {
        $city = trim($request->input('city'));
        $query->where(function ($q) use ($city) {
            $q->whereHas('source', function ($subQuery) use ($city) {
                $subQuery->whereHas('city', function ($sq) use ($city) {
                    $sq->where('name', 'like', '%' . $city . '%');
                });
            });
        });
    }

    if ($request->filled('state')) {
        $state = trim($request->input('state'));
        $query->where(function ($q) use ($state) {
            $q->whereHas('source', function ($subQuery) use ($state) {
                $subQuery->whereHas('state', function ($sq) use ($state) {
                    $sq->where('name', 'like', '%' . $state . '%');
                });
            });
        });
    }

    if ($request->filled('state')) {
        $state = trim($request->input('state'));
        $query->where(function ($q) use ($state) {
            $q->whereHas('source', function ($subQuery) use ($state) {
                $subQuery->whereHas('state', function ($sq) use ($state) {
                    $sq->where('name', 'like', '%' . $state . '%');
                });
            });
        });
    }

    if ($request->filled('postal_code')) {
        $postal_code = trim($request->input('postal_code'));
        $query->where(function ($q) use ($postal_code) {
            $q->whereHas('source', function ($subQuery) use ($postal_code) {
                $subQuery->where('postal_code', 'like', '%' . $postal_code . '%');
            });
        });
    }

    
    if ($request->filled('ward_no')) {
        $ward_no = trim($request->input('ward_no'));
        $query->where(function ($q) use ($ward_no) {
            $q->whereHas('source', function ($subQuery) use ($ward_no) {
                $subQuery->where('ward_no', 'like', '%' . $ward_no . '%');
            });
        });
    }
    
    
    if ($request->filled('colony')) {
        $colony = trim($request->input('colony'));
        $query->where(function ($q) use ($colony) {
            $q->whereHas('source', function ($subQuery) use ($colony) {
                $subQuery->whereHas('colony', function ($sq) use ($colony) {
                    $sq->where('name', 'like', '%' . $colony . '%');
                });
            });
        });
    }

      
    if ($request->filled('booth')) {
        $booth = trim($request->input('booth'));
        $query->where(function ($q) use ($booth) {
            $q->whereHas('source', function ($subQuery) use ($booth) {
                $subQuery->whereHas('booth', function ($sq) use ($booth) {
                    $sq->where('name', 'like', '%' . $booth . '%');
                });
            });
        });
    }

    ///////////
    ///////////
    ///////////
    
    // Select distinct sources
    $query->select('source')->distinct();
    // Paginate the result

    $count = $query->select('source')->distinct()->count();
    $ecidatas = $query->paginate(50);
     
    $totalChildrenCount = $this->getTotalChildrenCount($_GET['edi_users_id']);

    return view('user.ecidata.family', compact('ecidatas', 'distinctTotal', 'totalChildrenCount'));
     
}

public function getTotalChildrenCount($edi_users_id)
{
    // Step 1: Get all DISTINCT sources for the given edi_users_id
    $sources = Relation::where('edi_users_id', $edi_users_id)
        ->distinct()
        ->pluck('source')
        ->toArray();

    $totalChildrenCount = 0;

    // Step 2: For each source, count all its children
    foreach ($sources as $source) {
        $parentIds = Relation::where('source', $source)
            ->where('edi_users_id', $edi_users_id)
            ->pluck('parent')
            ->toArray();

        // Count children where parent matches the collected parent IDs
        $childrenCount = Relation::whereIn('parent', $parentIds)
            ->where('source', $source)
            ->where('edi_users_id', $edi_users_id)
            ->count();

        $totalChildrenCount += $childrenCount; // Add to the total count
    }

    return $totalChildrenCount;
}


public function export_family(Request $request)
    {
        $ecidatas = array();

        $sources = Relation::where('edi_users_id', $request->edi_users_id)->distinct()->pluck('source')->toArray();
        foreach ($sources as $source) {
            $parentIds = Relation::where('source', $source)
                ->where('edi_users_id', $request->edi_users_id)
                ->pluck('parent')
                ->toArray();
    
            $parntData = EciData::with(['country', 'state', 'city', 'polling_station', 'booth_number', 'colony'])->where('id',$source)->get()->first();
            // Count children where parent matches the collected parent IDs
            $childrenIds = Relation::whereIn('parent', $parentIds)
                ->where('source', $source)
                ->where('edi_users_id', $request->edi_users_id)
                ->get();

            foreach($childrenIds as $row){

                $childData = EciData::with(['country', 'state', 'city', 'polling_station', 'booth_number', 'colony'])->where('id',$row->parent)->get()->first();

                array_push($ecidatas, array(
                    "a" => $parntData->votar_name,
                    "b" => $parntData->relative_name,
                    "c" => $parntData->votar_id_no,
                    "d" => $parntData->mobile,
                    "e" => $parntData->booth_number->name,
                    "f" => $parntData->sl_no,
                    "g" => $parntData->polling_station->name,

                    "h" => $childData->votar_name,
                    "i" => $childData->relative_name,
                    "j" => $childData->votar_id_no,
                    "k" => $childData->mobile,
                    "l" => $childData->booth_number->name,
                    "m" => $childData->sl_no,
                    "n" => $childData->polling_station->name
                ));
            }
        }

        // Define CSV headers for each section side by side
        $headers = [
            '', '', '', 'VOTER DETAILS', '', '', '',
            '', '', '', 'FAMILY DETAIL', '', '', ''
        ];
        $subHeaders = [
            'NAME', 'RELATIVE NAME', 'VOTAL ID', 'MOBILE NUMBER', 'BOOTH', 'SL NO', 'POOLING STATION',
            'NAME', 'RELATIVE NAME', 'VOTAL ID', 'MOBILE NUMBER', 'BOOTH', 'SL NO', 'POOLING STATION'
        ];

        // Open the output stream
        $callback = function() use ($ecidatas, $headers, $subHeaders) {
            $file = fopen('php://output', 'w');

            // Add main section headers
            fputcsv($file, $headers);

            // Add sub-headers for both Voter and Family details side by side
            fputcsv($file, $subHeaders);

            // Loop through each ECI data entry
            foreach ($ecidatas as $data) {
                fputcsv($file, [
                    // Voter Details
                    $data['a'],
                    $data['b'],
                    $data['c'],
                    $data['d'],
                    $data['e'],
                    $data['f'],
                    $data['g'],
                    $data['h'],
                    $data['i'],
                    $data['j'],
                    $data['k'],
                    $data['l'],
                    $data['m'],
                    $data['n'],
                ]);
            }

            fclose($file);
        };

        // Return response as CSV
        return response()->stream($callback, 200, [
            "Content-type" => "text/csv",
            "Content-Disposition" => "attachment; filename=family_data.csv",
            "Pragma" => "no-cache",
            "Cache-Control" => "must-revalidate, post-check=0, pre-check=0",
            "Expires" => "0"
        ]);

    }

}
