<?php
// app/Http/Controllers/ECIUserController.php

namespace App\Http\Controllers\All;

use App\Models\EciUser;
use App\Models\EciData;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;

class ECIUserController extends Controller
{
    public function index(Request $request)
    {
        $query = EciUser::query();

        // Apply filters based on request input
        if ($request->has('name') && $request->name != "") {
            $query->where('name', 'like', '%' . $request->input('name') . '%');
        }
    
        if ($request->has('email') && $request->email != "") {
            $query->where('email', 'like', '%' . $request->input('email') . '%');
        }
        
        $eciusers = $query->paginate(50);

        return view('user.eciuser.index', compact('eciusers'));
    }

    public function create()
    {
        return view('user.eciuser.create');
    }

    public function store(Request $request)
    {
        //dd($_REQUEST);
        $request->validate([
            'name' => 'required|string',
            'email' => 'required|string',
            'password' => 'required|string',
        ]);

       
        EciUser::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => $request->password
        ]);

        return redirect()->route('user.eciuser.index')->with('success', 'Eci user added successfully');
    }

    public function edit($id)
    {
        $eciuser = EciUser::findOrFail($id);
        return view('user.eciuser.edit', compact('eciuser'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string',
            'email' => 'required|string',
            'password' => 'required|string',
        ]);
    
        $eciuser = EciUser::findOrFail($id);
    
        $EciUser = EciUser::updateOrCreate(
            ['id' => $eciuser->id],
            [
                'name' => $request->name,
                'email' =>$request->email,
                'password' => $request->password,
            ]
        );
        
        return redirect()->route('user.eciuser.index')->with('success', 'Eci user updated successfully');
    }

    public function destroy($id)
    {
        // Find the MCQ category by ID
        $eciuser = EciUser::findOrFail($id);
    
        // Delete the MCQ category
        $eciuser->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.eciuser.index')->with('success', 'Eci user deleted successfully');
    }

    public function allEciUsers(Request $request)
    {
        $arr = [];
        $videos = EciUser::where()->get([
            'email',  'name', 
            'password'
        ]);
        
        foreach($videos as $video){
            array_push($arr, array(
                'name' => $video->name,
                'email' => $video->email, 
                'password' => $video->password
            ));  
        }
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $arr));
    }
    
    
    public function forceLogout(Request $request)
    {
         EciUser::updateOrCreate(
                    ['email' => $request->email],
                    [
                        'device_id' => ""
                    ]
                );
        
        return redirect()->route('user.eciuser.index')->with('success', 'Logout successful');
    }


    public function export_family(Request $request)
    {
        $ecidatas = array();
        $EciUserData = EciUser::all();
        
        foreach ($EciUserData as $source) {
            $userSourceCount =  EciData::userCount($source->id );
            $familyCount =  EciData::getTotalChildrenCount($source->id );
            array_push($ecidatas, array(
                "a" => $source->name,
                "b" => $source->email,
                "c" => $source->password,
                "d" => $userSourceCount,
                "e" => $familyCount
            ));
        }
       
        // Define CSV headers for each section side by side
        $headers = [
            'Name', 'Email', 'Password', 'Total', 'Family'
        ];

        // Open the output stream
        $callback = function() use ($ecidatas, $headers) {
            $file = fopen('php://output', 'w');

            // Add main section headers
            fputcsv($file, $headers);

            
            // Loop through each ECI data entry
            foreach ($ecidatas as $data) {
                fputcsv($file, [
                    // Voter Details
                    $data['a'],
                    $data['b'],
                    $data['c'],
                    $data['d'],
                    $data['e']
                ]);
            }

            fclose($file);
        };

        // Return response as CSV
        return response()->stream($callback, 200, [
            "Content-type" => "text/csv",
            "Content-Disposition" => "attachment; filename=user_data.csv",
            "Pragma" => "no-cache",
            "Cache-Control" => "must-revalidate, post-check=0, pre-check=0",
            "Expires" => "0"
        ]);

    }
}
