<?php
// app/Http/Controllers/ImageController.php

namespace App\Http\Controllers\All;

use App\Models\Video;
use App\Models\VideoTranslation;
use App\Models\Language;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;

class ImageController extends Controller
{
    public function index()
    {
         
        $defaultLanguage = Language::where('is_default', true)->value('id') ?? 1;
        $galleries = VideoTranslation::where('language_id', $defaultLanguage)->paginate(50);
        return view('user.video.index', compact('galleries'));
    }

    public function create()
    {
        $languages = Language::all();

        return view('user.video.create', compact('languages'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'videos_path' => 'required|url', // Adjust validation rules for image upload
            'names.*' => 'required|string', // Adjust validation rules for category titles
        ]);
        
        // Create Video
        $video = Video::create();

        if ($request->has('translations')) {
            // Create translations for each language
            foreach ($request->translations as $languageId => $translation) {
                VideoTranslation::create([
                    'video_id' => $video->id,
                    'language_id' => $languageId,
                    'title' => $translation['title'],
                    'videos_path' => $request->input('videos_path')
                ]);
                
            }
        }

        return redirect()->route('user.video.index')->with('success', 'Video added successfully');
    }

    public function edit($id)
    {
        $video = Video::findOrFail($id);
        $languages = Language::all(); // You may need to adjust this based on your language setup
    
        return view('user.video.edit', compact('video', 'languages'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'videos_path' => 'required|url', // Adjust validation rules for image upload
            'names.*' => 'required|string', // Adjust validation rules for category titles
        ]);
    
        $video = Video::findOrFail($id);
    
        foreach ($request->input('translations') as $languageCode => $translation) {
        
            // Find or create the translation record based on mcq_id and language_id
            $mcqTranslation = VideoTranslation::updateOrCreate(
                ['video_id' => $video->id, 'language_id' => $languageCode],
                [
                    'title' => $translation['title'],
                    'videos_path' => $request->input('videos_path')
                ]
            );
        }
        
        
        return redirect()->route('user.video.index')->with('success', 'Video updated successfully');
    }

    public function destroy($id)
    {
        // Find the MCQ category by ID
        $mcq = Video::findOrFail($id);
    
        // Delete translations associated with the category
        $mcq->translations()->delete();
    
        // Delete the MCQ category
        $mcq->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.video.index')->with('success', 'Video deleted successfully');
    }
}
