<?php
// app/Http/Controllers/PageController.php

namespace App\Http\Controllers\All;

use App\Models\Page;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;

class PageController extends Controller
{
    public function index()
    {
        $pages = Page::where([])->paginate(50);
        return view('user.page.index', compact('pages'));
    }

    public function create()
    {
        return view('user.page.create');
    }

    public function store(Request $request)
    {
        //dd($_REQUEST);
        $request->validate([
            'title' => 'required|string',
            'descriptions' => 'required|string',
        ]);

       
        Page::create([
            'title' => $request->title,
            'descriptions' => $request->descriptions
        ]);

        return redirect()->route('user.page.index')->with('success', 'Page added successfully');
    }

    public function edit($id)
    {
        $page = Page::findOrFail($id);
        return view('user.page.edit', compact('page'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'title' => 'required|string',
            'descriptions' => 'required|string',
        ]);
    
        $page = Page::findOrFail($id);
    
        $Page = Page::updateOrCreate(
            ['id' => $page->id],
            [
                'title' =>$request->title,
                'descriptions' => $request->descriptions,
            ]
        );
        
        return redirect()->route('user.page.index')->with('success', 'Page updated successfully');
    }

    public function destroy($id)
    {
        // Find the MCQ category by ID
        $page = Page::findOrFail($id);
    
        // Delete the MCQ category
        $page->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.page.index')->with('success', 'Page deleted successfully');
    }

    public function allPages(Request $request)
    {
        $arr = [];
        $videos = Page::where()->get([
            'title', 
            'descriptions'
        ]);
        
        foreach($videos as $video){
            array_push($arr, array(
                'title' => $video->title, 
                'descriptions' => $video->descriptions
            ));  
        }
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $arr));
    }
}
