<?php
// app/Http/Controllers/PollingStationController.php

namespace App\Http\Controllers\All;
use App\Models\EciData;
use App\Models\PollingStation;
use App\Models\Country;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\PoolingImport;

class PollingStationController extends Controller
{
    public function index()
    {
        $pollings = PollingStation::where([])->orderBy('id' , 'desc')->paginate(50);
        return view('user.polling.index', compact('pollings'));
    }

    public function truncate()
    {
        PollingStation::truncate();
        return redirect()->back()->with('success', 'Data deleted successfully.');
    }

    public function create()
    {
        $country = Country::all();
        return view('user.polling.create', compact('country'));
    }

    public function store(Request $request)
    {
        //dd($_REQUEST);
        $request->validate([
            'name' => 'required|string'
        ]);

       
        PollingStation::create([
            'name' => $request->name
        ]);

        return redirect()->route('user.polling.index')->with('success', 'PollingStation added successfully');
    }

    public function edit($id)
    {
        $country = Country::all();
        $polling = PollingStation::findOrFail($id);
        return view('user.polling.edit', compact('polling','country'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string'
        ]);
    
        $polling = PollingStation::findOrFail($id);
    
        $PollingStation = PollingStation::updateOrCreate(
            ['id' => $polling->id],
            [
                'name' => $request->name
            ]
        );
        
        return redirect()->route('user.polling.index')->with('success', 'PollingStation updated successfully');
    }

    public function destroy($id)
    {

        $EciData = EciData::where(['polling_station_id' => $id])->first();
        if($EciData){
            return redirect()->route('user.booth.index')->with('error', 'BoothNumber linked with ECI data');
        }

        // Find the MCQ category by ID
        $polling = PollingStation::findOrFail($id);
    
        // Delete the MCQ category
        $polling->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.polling.index')->with('success', 'PollingStation deleted successfully');
    }

    public function allPollingStations(Request $request)
    {
        $arr = [];
        $videos = PollingStation::where()->get([
            'title', 
            'descriptions'
        ]);
        
        foreach($videos as $video){
            array_push($arr, array(
                'title' => $video->title, 
                'descriptions' => $video->descriptions
            ));  
        }
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $arr));
    }

    public function import(Request $request)
    {
        // Validate the file input
        $request->validate([
            'file' => 'required|mimes:csv,xlsx'
        ]);

        // Perform the import
        Excel::import(new PoolingImport, $request->file('file'));

        return redirect()->back()->with('success', 'File imported successfully.');
    }

    public function bulkDelete(Request $request)
    {
        $ids = $request->input('ids');
        
        if ($ids) {
            // Check if any of the selected polling stations are linked with ECI data
            $eciLinkedStations = EciData::whereIn('polling_station_id', $ids)->get();
            
            if ($eciLinkedStations->isNotEmpty()) {
                return redirect()->back()->with('error', 'Some booths are linked with ECI data and cannot be deleted.');
            }
    
            // Proceed to delete polling stations that are not linked with ECI data
            PollingStation::whereIn('id', $ids)->delete();
            return redirect()->back()->with('success', 'Selected data deleted successfully.');
        }
    
        return redirect()->back()->with('error', 'No data selected for deletion.');
    }
}
