<?php
// app/Http/Controllers/WordNumberController.php

namespace App\Http\Controllers\All;
use App\Models\EciData;
use App\Models\WordNumber;
use App\Models\Country;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Http\Controllers\Controller;
use Maatwebsite\Excel\Facades\Excel;
use App\Imports\WordsImport;

class WordNumberController extends Controller
{
    public function index()
    {
        $booths = WordNumber::where([])->orderBy('id' , 'desc')->paginate(50);
        return view('user.word.index', compact('booths'));
    }

    public function truncate()
    {
        WordNumber::truncate();
        return redirect()->back()->with('success', 'Data deleted successfully.');
    }

    public function create()
    {
        $country = Country::all();
        return view('user.word.create', compact('country'));
    }

    public function store(Request $request)
    {
        //dd($_REQUEST);
        $request->validate([
            'name' => 'required|string'
        ]);

       
        WordNumber::create([
            'name' => $request->name
        ]);

        return redirect()->route('user.word.index')->with('success', 'WordNumber added successfully');
    }

    public function edit($id)
    {
        $country = Country::all();
        $booth = WordNumber::findOrFail($id);
        return view('user.word.edit', compact('booth','country'));
    }
    

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string'
        ]);
    
        $booth = WordNumber::findOrFail($id);
    
        $WordNumber = WordNumber::updateOrCreate(
            ['id' => $booth->id],
            [
                'name' => $request->name
            ]
        );
        
        return redirect()->route('user.word.index')->with('success', 'WordNumber updated successfully');
    }

    public function destroy($id)
    {

        $EciData = EciData::where(['booth_number_id' => $id])->first();
        if($EciData){
            return redirect()->route('user.word.index')->with('error', 'WordNumber linked with ECI data');
        }
        // Find the MCQ category by ID
        $booth = WordNumber::findOrFail($id);
    
        // Delete the MCQ category
        $booth->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.word.index')->with('success', 'WordNumber deleted successfully');
    }

    public function allWordNumbers(Request $request)
    {
        $arr = [];
        $videos = WordNumber::where()->get([
            'title', 
            'descriptions'
        ]);
        
        foreach($videos as $video){
            array_push($arr, array(
                'title' => $video->title, 
                'descriptions' => $video->descriptions
            ));  
        }
        
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $arr));
    }

    

    public function import(Request $request)
    {
        // Validate the file input
        $request->validate([
            'file' => 'required|mimes:csv,xlsx'
        ]);

        // Perform the import
        Excel::import(new WordsImport, $request->file('file'));

        return redirect()->back()->with('success', 'File imported successfully.');
    }

    public function bulkDelete(Request $request)
{
    $ids = $request->input('ids');
    
    if ($ids) {
        // Check if any of the selected word numbers are linked with ECI data
        $eciLinkedWords = EciData::whereIn('ward_no', $ids)->get();
        
        if ($eciLinkedWords->isNotEmpty()) {
            return redirect()->back()->with('error', 'Some Word Numbers are linked with ECI data and cannot be deleted.');
        }

        // Proceed to delete word numbers that are not linked with ECI data
        WordNumber::whereIn('id', $ids)->delete();
        return redirect()->back()->with('success', 'Selected Word Numbers deleted successfully.');
    }

    return redirect()->back()->with('error', 'No Word Numbers selected for deletion.');
}

}
