<?php
namespace App\Imports;
use Illuminate\Support\Facades\DB;
use App\Models\EciData;
use App\Models\User;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\WithHeadingRow;

class UsersImport implements ToModel, WithHeadingRow
{
    protected $rows = [];

public function model(array $row)
{
    try {
    // Disable foreign key checks
    \DB::statement('SET FOREIGN_KEY_CHECKS=0;');

    // Clean up special characters from each value in the row
    foreach ($row as $key => $value) {
        // Ensure value is a string, just in case it's not (e.g., null or numbers)
        if (is_string($value)) {
            // 1. Remove invisible characters (e.g., zero-width, non-breaking spaces)
            $value = preg_replace('/[\x00-\x1F\x7F\xA0]/u', '', $value);

            // 2. Remove all special characters except alphanumerics, basic punctuation
            $value = preg_replace('/[^A-Za-z0-9\- .,@]/u', '', $value);

            // 3. Trim the cleaned value to remove leading and trailing spaces
            $row[$key] = trim($value);
        } else {
            // For non-string values, just keep them as they are (int, null, etc.)
            $row[$key] = $value;
        }
    }

    // Dump the cleaned row to see what data is being passed
    
    $this->rows[] = $row;

    // Try to find an existing record with the given votar_id_no
    $user = EciData::where('votar_id_no', $row['votar_id_no'])->first();

    // If the record does not exist, create a new instance
    if (!$user) {
        $user = new EciData();
    }

    // Assign the values
    $user->edi_users_id = $row['edi_users_id'];
    $user->ac_no = $row['ac_no'];
    $user->country_id = $row['country_id'];
    $user->city_id = $row['city_id'];
    $user->state_id = $row['state_id'];
    $user->postal_code = $row['postal_code'];
    $user->booth_number_id = $row['booth_number_id'];
    $user->ward_no = $row['ward_no'];
    $user->part_no = $row['part_no'];
    $user->section = $row['section'];
    $user->sl_no = $row['sl_no'];
    $user->votar_id_no = $row['votar_id_no'];
    $user->votar_name = $row['votar_name'];
    $user->mobile = $row['mobile'];
    $user->house_number = $row['house_number'];
    $user->age = $row['age'];
    $user->sex = $row['sex'];
    $user->polling_station_id = $row['polling_station_id'];
    $user->colony_id = $row['colony_id'];
    $user->block = $row['block'];
    $user->gali_no_id = $row['gali_no_id'];
    $user->votar_id_front = $row['votar_id_front'];
    $user->votar_id_back = $row['votar_id_back'];
    $user->relation = $row['relation'];
    $user->relative_name = $row['relative_name'];
    $user->parent_state = $row['parent_state'];
    $user->parent_district = $row['parent_district'];
    $user->religion = $row['religion'];
    $user->cast = $row['cast'];
    $user->dob = $row['dob'];
    $user->marriage_date = $row['marriage_date'];
    $user->profession = $row['profession'];
    $user->remarks = $row['remarks'];

    // Save the record (insert or update) and check if it's successful
    if ($user->save()) {
        // Re-enable foreign key checks
        \DB::statement('SET FOREIGN_KEY_CHECKS=1;');
        return $user;
    } else {
        // Log failure to save
        \Log::error('Failed to save user: ' . json_encode($row));
        return null;
    }
} catch (\Exception $e) {
    // Log the error message
    \Log::error('Error processing row: ' . json_encode($row) . ' - Exception: ' . $e->getMessage());

    // Optionally return null or handle it differently based on your use case
    return null;
}


}


    
}
