<?php

// EciData.php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class EciData extends Model
{
    protected $fillable = [
        'edi_users_id', 
        'ac_no',
        'ward_no',
        'part_no',
        'section',
        'sl_no',
        'votar_id_no',
        'votar_name',
        'mobile',
        'house_number',
        'age',
        'sex',
        'polling_station_id',
        'colony_id',
        'block',
        'gali_no_id',
        'votar_id_front',
        'votar_id_back',
        'country_id',
        'city_id',
        'state_id',
        'postal_code',
        'booth_number_id',

        'relative_name',
        'parent_state',
        'parent_district',
        'religion',
        'cast',
        'dob',
        'marriage_date',
        'profession',
        'remarks'
    ];

    public function country()
    {
        return $this->belongsTo(Country::class, 'country_id');
    }

    public function state()
    {
        return $this->belongsTo(State::class, 'state_id');
    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    

    public function polling_station()
    {
        return $this->belongsTo(PollingStation::class, 'polling_station_id');
    }

    public function booth_number()
    {
        return $this->belongsTo(BoothNumber::class, 'booth_number_id');
    }

    public function colony()
    {
        return $this->belongsTo(Colony::class, 'colony_id');
    }
    
    ////////
    ///////

    public function getFamilyTree($parent_id,$edi_users_id) {
        $currentRelation = Relation::where('source', $parent_id)->where('edi_users_id', $edi_users_id)->get();
        $parentIds = $currentRelation->pluck('parent')->toArray();
        if($currentRelation){
        $children = Relation::whereIn('parent', $parentIds)->where('source', $parent_id)->where('edi_users_id', $edi_users_id)->get();
        foreach ($children as $child) {
            // Fetch related data for each edi_users_id dynamically
            $childData = EciData::where('id', $child->parent)->first();
            if ($childData) {
                // Load related data like city, state, etc.
                $childData->load('city', 'state', 'polling_station', 'colony', 'country', 'booth_number');
            }
            // Add childData to the child relation
            $child['data'] = $childData;
            $child['descendants'] = [];
        }
        return $children;
        }else {
            return [];
        }
    }
    
   // Static function to get the distinct count of sources for a user
   public static function userCount($edi_users_id)
   {
       return Relation::where('edi_users_id', $edi_users_id)->distinct('source')->count('source');
   }
   

   public static function userCountAll()
   {
        $total = 0;
        $all = EciUser::all();
        foreach ($all as $row) {
            $ttl = Relation::where('edi_users_id',  $row->id)->distinct('source')->count('source');
            $total += $ttl;
        }
        return $total;
   }

   public static function getTotalChildrenCount($edi_users_id)
{
    // Step 1: Get all DISTINCT sources for the given edi_users_id
    $sources = Relation::where('edi_users_id', $edi_users_id)
        ->distinct()
        ->pluck('source')
        ->toArray();

    $totalChildrenCount = 0;

    // Step 2: For each source, count all its children
    foreach ($sources as $source) {
        $parentIds = Relation::where('source', $source)
            ->where('edi_users_id', $edi_users_id)
            ->pluck('parent')
            ->toArray();

        // Count children where parent matches the collected parent IDs
        $childrenCount = Relation::whereIn('parent', $parentIds)
            ->where('source', $source)
            ->where('edi_users_id', $edi_users_id)
            ->count();

        $totalChildrenCount += $childrenCount; // Add to the total count
    }

    return $totalChildrenCount;
}



public static function getTotalChildrenCountAll()
{
    $total = 0;
    $all = EciUser::all();
     
    foreach ($all as $row) {
        // Step 1: Get all DISTINCT sources for the given edi_users_id
        $sources = Relation::where('edi_users_id', $row->id)
            ->distinct()
            ->pluck('source')
            ->toArray();
    
        $totalChildrenCount = 0;

        // Step 2: For each source, count all its children
        foreach ($sources as $source) {
            $parentIds = Relation::where('source', $source)
                ->where('edi_users_id', $row->id)
                ->pluck('parent')
                ->toArray();

            // Count children where parent matches the collected parent IDs
            $childrenCount = Relation::whereIn('parent', $parentIds)
                ->where('source', $source)
                ->where('edi_users_id', $row->id)
                ->count();

            $totalChildrenCount += $childrenCount; // Add to the total count
        }
        $total += $totalChildrenCount;
    }
   
    return $total;
}


    /////////
    /////////
    
}
