@extends('layouts.user.userdashboard')

@section('content')
<main class="content">
    <div class="pe-1">

        <div class="row mb-2 mb-xl-3">
            <div class="col-auto d-none d-sm-block">
                <h3 class="txt_default">Manage Colony</h3>
            </div>
            <div class="col-auto d-none d-sm-block">
                <button type="button" class="btn btn-info" data-toggle="modal" data-target="#import">Import Data</button>
                <a href="{{ asset('/sample_data.csv') }}" target="_blank" class="btn btn-warning">Sample Data</a>
                <button type="button" id="deleteSelected" class="btn btn-danger">Delete Selected</button>
                <a href="{{ route('user.colony.truncate') }}" class="btn btn-danger  ">Truncate</a>
            </div>
        </div>
        
        <div class="row">
            <div class="col-12 col-md-12">
                <div class="card flex-fill w-100">
                    <div class="card-body px-4">

                        @if(session('success'))
                            <div class="alert alert-success p-3" role="alert">
                                {{ session('success') }}
                            </div>
                        @endif

                        @if(session('error'))
                            <div class="alert alert-danger p-3" role="alert">
                                {{ session('error') }}
                            </div>
                        @endif

                        <table class="table table-hover my-0">
                            <thead>
                                <tr>
                                    <th><input type="checkbox" id="checkAll"></th>
                                    <th>#</th>
                                    <th>Colony</th>
                                    <th>Action</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($colonys as $colony)
                                    <tr>
                                        <td><input type="checkbox" class="checkItem" value="{{ $colony->id }}"></td>
                                        <td>{{ $colony->id }}</td>
                                        <td>{{ $colony->name }}</td>
                                        <td>
                                            <a href="{{ route('user.colony.edit', ['id' => $colony->id]) }}" class="btn btn-primary">Edit</a>
                                            <form id="deleteForm{{ $colony->id }}" action="{{ route('user.colony.destroy', $colony->id) }}" method="post" style="display: inline;">
                                                @csrf
                                                @method('DELETE')
                                                <button type="button" class="btn btn-danger" onclick="confirmDelete('{{ $colony->id }}')">Delete</button>
                                            </form>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td colspan="4">No colony found</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>

                        <div class="pagination-container text-center">
                            {{ $colonys->links() }}
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
</main>
@endsection

<div class="modal fade" id="import" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Import excel</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form method="POST" enctype="multipart/form-data" action="{{ route('user.colony.import') }}">
                    @csrf
                    <input type="file" name="file" required class="form-control">
                    <br/>
                    <button type="submit" class="btn btn-primary">Import excel</button>
                </form>
            </div>
        </div>
    </div>
</div>

@section('script')
<script>
function confirmDelete(colonyId) {
    Swal.fire({
        title: 'Are you sure?',
        text: 'You won\'t be able to revert this!',
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#d33',
        cancelButtonColor: '#3085d6',
        confirmButtonText: 'Yes, delete it!'
    }).then((result) => {
        if (result.isConfirmed) {
            submitForm('deleteForm' + colonyId);
        }
    });
}

function submitForm(formId) {
    var form = document.getElementById(formId);
    form.submit();
}

// Check All / Uncheck All functionality
document.getElementById('checkAll').addEventListener('click', function() {
    const checkboxes = document.querySelectorAll('.checkItem');
    checkboxes.forEach((checkbox) => {
        checkbox.checked = this.checked;
    });
});

// Handle individual checkbox and toggle "Check All"
document.querySelectorAll('.checkItem').forEach((checkbox) => {
    checkbox.addEventListener('change', function() {
        if (!this.checked) {
            document.getElementById('checkAll').checked = false;
        } else if (document.querySelectorAll('.checkItem:checked').length === document.querySelectorAll('.checkItem').length) {
            document.getElementById('checkAll').checked = true;
        }
    });
});

// Handle delete selected
document.getElementById('deleteSelected').addEventListener('click', function() {
    const selectedIds = Array.from(document.querySelectorAll('.checkItem:checked')).map(checkbox => checkbox.value);

    if (selectedIds.length === 0) {
        Swal.fire({
            icon: 'error',
            title: 'No items selected',
            text: 'Please select items to delete.',
        });
        return;
    }

    Swal.fire({
        title: 'Are you sure?',
        text: 'You won\'t be able to revert this!',
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#d33',
        cancelButtonColor: '#3085d6',
        confirmButtonText: 'Yes, delete them!'
    }).then((result) => {
        if (result.isConfirmed) {
            deleteSelectedColonies(selectedIds);
        }
    });
});

function deleteSelectedColonies(ids) {
    const form = document.createElement('form');
    form.method = 'POST';
    form.action = "{{ route('user.colony.bulkDelete') }}";
    
    const csrfInput = document.createElement('input');
    csrfInput.type = 'hidden';
    csrfInput.name = '_token';
    csrfInput.value = "{{ csrf_token() }}";
    form.appendChild(csrfInput);

    ids.forEach(id => {
        const input = document.createElement('input');
        input.type = 'hidden';
        input.name = 'ids[]';
        input.value = id;
        form.appendChild(input);
    });

    document.body.appendChild(form);
    form.submit();
}
</script>
@endsection
