<?php

// Facades
use Illuminate\Support\Facades\{
    Auth,
    Route
};

// Admin Restful Controllers
use App\Http\Controllers\All\ProfileController;
use App\Http\Controllers\All\PageController;
use App\Http\Controllers\All\CmsController;
use App\Http\Controllers\All\ECIUserController;
use App\Http\Controllers\All\ECIDataController;
use App\Http\Controllers\All\BoothNumberController;
use App\Http\Controllers\All\PollingStationController;
use App\Http\Controllers\All\ColonyController;
use App\Http\Controllers\All\WordNumberController;

use App\Http\Controllers\Admin\{
    ActivityLogController,
    DashboardController,
    UserController
};

// USer - Restful Controllers
use App\Http\Controllers\User\{
    ActivityLogController as UserActivityLogController,
    DashboardController as UserDashboardController,
};

// Shared Restful Controllers
use App\Http\Controllers\All\{
    TmpImageUploadController
};


Route::get('/', function () {
    return redirect(route('login'));
});


// Admin
Route::group(['middleware' => ['auth', 'admin'], 'prefix' => 'admin', 'as' => 'admin.'],function() {
    Route::resource('dashboard', DashboardController::class);
    Route::resource('user', UserController::class);
    Route::resource('activity', ActivityLogController::class);
});


// User
Route::group(['middleware' => ['auth'], 'prefix' => 'user', 'as' => 'user.'],function() {
        Route::resource('dashboard', UserDashboardController::class);
        Route::resource('activity', UserActivityLogController::class);

        Route::get('/admin/cms', [CmsController::class, 'edit'])->name('cms.edit');
        Route::put('/admin/cms/update', [CmsController::class, 'update'])->name('cms.update');

        Route::get('/admin/page', [PageController::class, 'index'])->name('page.index');
        Route::get('/admin/page/create', [PageController::class, 'create'])->name('page.create');
        Route::post('/admin/page/store', [PageController::class, 'store'])->name('page.store');
        Route::get('/admin/page/edit/{id}', [PageController::class, 'edit'])->name('page.edit');
        Route::put('/admin/page/update/{id}', [PageController::class, 'update'])->name('page.update');
        Route::delete('/admin/page/destroy/{id}', [PageController::class, 'destroy'])->name('page.destroy');

        Route::get('/admin/eciuser', [ECIUserController::class, 'index'])->name('eciuser.index');
        
        Route::get('/admin/eciuser/logout', [ECIUserController::class, 'forceLogout'])->name('eciuser.forceLogout');
        
        Route::get('/admin/eciuser/create', [ECIUserController::class, 'create'])->name('eciuser.create');
        Route::post('/admin/eciuser/store', [ECIUserController::class, 'store'])->name('eciuser.store');
        Route::get('/admin/eciuser/edit/{id}', [ECIUserController::class, 'edit'])->name('eciuser.edit');
        Route::put('/admin/eciuser/update/{id}', [ECIUserController::class, 'update'])->name('eciuser.update');
        Route::delete('/admin/eciuser/destroy/{id}', [ECIUserController::class, 'destroy'])->name('eciuser.destroy');
        Route::get('/admin/eciuser/family', [ECIDataController::class, 'family'])->name('eciuser.family');
        Route::get('/admin/eciuser/export_eciuser', [ECIUserController::class, 'export_family'])->name('eciuser.export_eciuser');

        Route::get('/admin/ecidata', [ECIDataController::class, 'index'])->name('ecidata.index');
        Route::get('/admin/ecidata/create', [ECIDataController::class, 'create'])->name('ecidata.create');
        Route::post('/admin/ecidata/store', [ECIDataController::class, 'store'])->name('ecidata.store');
        Route::get('/admin/ecidata/edit/{id}', [ECIDataController::class, 'edit'])->name('ecidata.edit');
        Route::put('/admin/ecidata/update/{id}', [ECIDataController::class, 'update'])->name('ecidata.update');
        Route::put('/admin/ecidata/relationship', [ECIDataController::class, 'relationship'])->name('ecidata.relationship');
        Route::delete('/admin/ecidata/destroy/{id}', [ECIDataController::class, 'destroy'])->name('ecidata.destroy');
        Route::post('/admin/ecidata/import', [ECIDataController::class, 'import'])->name('ecidata.import');
        Route::post('/admin/ecidata/bulkDelete', [ECIDataController::class, 'bulkDelete'])->name('ecidata.bulkDelete');
        Route::get('/admin/ecidata/export', [EciDataController::class, 'export'])->name('ecidata.export');
        Route::get('/admin/ecidata/export_family', [EciDataController::class, 'export_family'])->name('ecidata.export_family');
        Route::get('/admin/ecidata/truncate', [ECIDataController::class, 'truncate'])->name('ecidata.truncate');

        Route::get('/admin/booth', [BoothNumberController::class, 'index'])->name('booth.index');
        Route::get('/admin/booth/create', [BoothNumberController::class, 'create'])->name('booth.create');
        Route::post('/admin/booth/store', [BoothNumberController::class, 'store'])->name('booth.store');
        Route::get('/admin/booth/edit/{id}', [BoothNumberController::class, 'edit'])->name('booth.edit');
        Route::put('/admin/booth/update/{id}', [BoothNumberController::class, 'update'])->name('booth.update');
        Route::delete('/admin/booth/destroy/{id}', [BoothNumberController::class, 'destroy'])->name('booth.destroy');
        Route::post('/admin/booth/importword', [BoothNumberController::class, 'import'])->name('booth.import');
        Route::post('/admin/booth/bulkDelete', [BoothNumberController::class, 'bulkDelete'])->name('booth.bulkDelete');
        Route::get('/admin/booth/truncate', [BoothNumberController::class, 'truncate'])->name('booth.truncate');


        Route::get('/admin/word', [WordNumberController::class, 'index'])->name('word.index');
        Route::get('/admin/word/create', [WordNumberController::class, 'create'])->name('word.create');
        Route::post('/admin/word/store', [WordNumberController::class, 'store'])->name('word.store');
        Route::get('/admin/word/edit/{id}', [WordNumberController::class, 'edit'])->name('word.edit');
        Route::put('/admin/word/update/{id}', [WordNumberController::class, 'update'])->name('word.update');
        Route::delete('/admin/word/destroy/{id}', [WordNumberController::class, 'destroy'])->name('word.destroy');
        Route::post('/admin/word/importword', [WordNumberController::class, 'import'])->name('word.import');
        Route::post('/admin/word/bulkDelete', [WordNumberController::class, 'bulkDelete'])->name('word.bulkDelete');
        Route::get('/admin/word/truncate', [WordNumberController::class, 'truncate'])->name('word.truncate');

        Route::get('/admin/polling', [PollingStationController::class, 'index'])->name('polling.index');
        Route::get('/admin/polling/create', [PollingStationController::class, 'create'])->name('polling.create');
        Route::post('/admin/polling/store', [PollingStationController::class, 'store'])->name('polling.store');
        Route::get('/admin/polling/edit/{id}', [PollingStationController::class, 'edit'])->name('polling.edit');
        Route::put('/admin/polling/update/{id}', [PollingStationController::class, 'update'])->name('polling.update');
        Route::delete('/admin/polling/destroy/{id}', [PollingStationController::class, 'destroy'])->name('polling.destroy');
        Route::post('/admin/polling/importword', [PollingStationController::class, 'import'])->name('polling.import');
        Route::post('/admin/polling/bulkDelete', [PollingStationController::class, 'bulkDelete'])->name('polling.bulkDelete');
        Route::get('/admin/polling/truncate', [PollingStationController::class, 'truncate'])->name('polling.truncate');

        Route::get('/admin/colony', [ColonyController::class, 'index'])->name('colony.index');
        Route::get('/admin/colony/create', [ColonyController::class, 'create'])->name('colony.create');
        Route::post('/admin/colony/store', [ColonyController::class, 'store'])->name('colony.store');
        Route::get('/admin/colony/edit/{id}', [ColonyController::class, 'edit'])->name('colony.edit');
        Route::put('/admin/colony/update/{id}', [ColonyController::class, 'update'])->name('colony.update');
        Route::delete('/admin/colony/destroy/{id}', [ColonyController::class, 'destroy'])->name('colony.destroy');
        Route::post('/admin/colony/importword', [ColonyController::class, 'import'])->name('colony.import');
        Route::post('/admin/colony/bulkDelete', [ColonyController::class, 'bulkDelete'])->name('colony.bulkDelete');
        Route::get('/admin/colony/truncate', [ColonyController::class, 'truncate'])->name('colony.truncate');

        Route::get('/admin/country', [CmsController::class, 'country'])->name('country');
        Route::get('/admin/state', [CmsController::class, 'state'])->name('state');
        Route::get('/admin/city', [CmsController::class, 'city'])->name('city');
        Route::get('/admin/pincode', [CmsController::class, 'pincode'])->name('pincode');
        Route::get('/admin/other', [CmsController::class, 'other'])->name('other');

});

// Auth
Route::group(['middleware' => ['auth']],function() {
    // TMP FILE UPLOAD
    Route::delete('tmp_upload/revert', [TmpImageUploadController::class, 'revert']);
    Route::post('tmp_upload/content', [TmpImageUploadController::class, 'faqImageUpload'])->name('tmpupload.faqImageUpload');
    Route::resource('tmp_upload', TmpImageUploadController::class);
    Route::resource('profile', ProfileController::class)->parameter('profile', 'user');;
  
});

Auth::routes(['register' => false]);